@@ -7,7 +7,7 @@
 #  define KCDDB_NO_EXPORT
 #else
 #  ifndef KCDDB_EXPORT
-#    ifdef KF5Cddb_EXPORTS
+#    ifdef KCddb_EXPORTS
         /* We are building this library */
 #      define KCDDB_EXPORT __attribute__((visibility("default")))
 #    else
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* KCDDB_EXPORT_H */
